Koverse Python client
=====================

A package that allows Python scripts to communicate with the Koverse server.

When you are ready to publish the updated version of this package:

 1. Build package source: `python setup.py build`
 2. Build distributable artifacts - `python setup.py bdist_wheel && python setup.py sdist` - and delete old tarballs and `whl` files